=====================
Leeeeon4 Test Package
=====================


.. image:: https://img.shields.io/pypi/v/leeeeon4_test_package.svg
        :target: https://pypi.python.org/pypi/leeeeon4_test_package

.. image:: https://img.shields.io/travis/leeeeon4/leeeeon4_test_package.svg
        :target: https://travis-ci.com/leeeeon4/leeeeon4_test_package

.. image:: https://readthedocs.org/projects/leeeeon4-test-package/badge/?version=latest
        :target: https://leeeeon4-test-package.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


.. image:: https://pyup.io/repos/github/leeeeon4/leeeeon4_test_package/shield.svg
     :target: https://pyup.io/repos/github/leeeeon4/leeeeon4_test_package/
     :alt: Updates



A test package created to learn best practices regarding creating packages.


* Free software: MIT license
* Documentation: https://leeeeon4-test-package.readthedocs.io.


Features
--------

* Can list ingredients as in presented course example.
* This is just a test. 

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

This package was build as part of the Course: `Creating and Distributing Python Packages`_. 

.. _`Creating and Distributing Python Packages`: https://twoscoopspress.thinkific.com/courses/creating-and-distributing-python-packages
